==> rwa_add_banner-0.0.4.tar.gz: lib/add_banner.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
class AddBanner extends StatelessWidget {
  AddBanner({
    Key? key,required this.listOfAddCard
  }) : super(key: key);

  final List<CardInList> listOfAddCard;

  @override
  Widget build(BuildContext context) {

    return LayoutBuilder(
      builder: (context,constraines){
        print(constraines.maxWidth);
        if(constraines.maxWidth >500){
          return Container(
            height: 160,
            width: MediaQuery.of(context).size.width,
            child: ListView.builder(
                scrollDirection: Axis.horizontal,
                itemCount: listOfAddCard.length,
                itemBuilder: (context,index){return
                  Container(
                      height: 160,
                      width: 400,child: getBanner(index));
                }),
          );
        }
        return Container(
          height: 160,
          child: PageView.builder(
              controller: PageController(
                viewportFraction: 0.9,
                initialPage: 0,
              ),
              itemCount: listOfAddCard.length,
              itemBuilder: (context,index){return
                getBanner(index);
              }),
        );
      },
    );
  }

  Padding getBanner(int index) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: GestureDetector(
        onTap: (){
          //   Get.to(() => GroupListPage(listOfExamInCard.list[index]));
        },
        child: SingleBanner(listOfAddCard: listOfAddCard,index:index),
      ),
    );
  }
}

class SingleBanner extends StatelessWidget {
  const SingleBanner({
    Key? key,
    required this.listOfAddCard,this.index = 0
  }) : super(key: key);
  final int index;
  final List<CardInList> listOfAddCard;

  @override
  Widget build(BuildContext context) {
    if(listOfAddCard[index].isImage){
      return Image(image: AssetImage(listOfAddCard[index].imageUrl),);


    }else{
      return Card(
        elevation:8,
        child: Stack(
          children: [
            Positioned(
                top: 20,
                right: 20,
                child: Hero(
                    tag:listOfAddCard[index].heading,
                    child:       Text(listOfAddCard[index].heading,style: GoogleFonts.actor(letterSpacing: 1.5,decoration: TextDecoration.none,fontWeight: FontWeight.bold,color: Colors.white,fontSize: kIsWeb?20:15),)
                )),
            Positioned(
              top: 20,
              left: 20,
              child: ClipRRect(
                borderRadius: BorderRadius.all(Radius.circular(20)),
                child: Container(
                  height: 40,
                  width: 40,
                  color: Colors.white,
                  child: Center(
                    child:Icon(Icons.list,color: Colors.black,),
                  ),
                ),
              ),
            ),
            Positioned(
              bottom: 10,
              left: 20,
              child: Container(
                width: 240,
                height: 40,
                child: Text(listOfAddCard[index].description,
                  overflow: TextOverflow.fade,
                  style: GoogleFonts.actor(color: Colors.white70),),
              ),
            ),
          ],
        ),color: listOfAddCard[index].cardBackground,
      );
    }

  }
}


class CardInList{
  CardType cardType = CardType.list;
  IconData icon = Icons.list;
  Color cardBackground ;
  String heading;
  String description = '';
  Function onTap;
  bool isImage;
  String imageUrl;
  CardInList({this.isImage = false,this.imageUrl = '',required this.heading,this.description = '',this.cardBackground = Colors.black87,required this.onTap});
}

enum CardType{
  list,
  advertisement,
}

==> rwa_add_banner-0.0.5.tar.gz: lib/add_banner.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
class AddBanner extends StatelessWidget {
  AddBanner({
    Key? key,required this.listOfAddCard
  }) : super(key: key);

  final List<CardInList> listOfAddCard;

  @override
  Widget build(BuildContext context) {

    return LayoutBuilder(
      builder: (context,constraines){
        print(constraines.maxWidth);
        if(constraines.maxWidth >500){
          return Container(
            height: 160,
            width: MediaQuery.of(context).size.width,
            child: ListView.builder(
                scrollDirection: Axis.horizontal,
                itemCount: listOfAddCard.length,
                itemBuilder: (context,index){return
                  Container(
                      height: 160,
                      width: 400,child: getBanner(index));
                }),
          );
        }
        return Container(
          height: 160,
          child: PageView.builder(
              controller: PageController(
                viewportFraction: 0.9,
                initialPage: 0,
              ),
              itemCount: listOfAddCard.length,
              itemBuilder: (context,index){return
                getBanner(index);
              }),
        );
      },
    );
  }

  Padding getBanner(int index) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: GestureDetector(
        onTap: (){
          //   Get.to(() => GroupListPage(listOfExamInCard.list[index]));
        },
        child: SingleBanner(listOfAddCard: listOfAddCard,index:index),
      ),
    );
  }
}

class SingleBanner extends StatelessWidget {
  const SingleBanner({
    Key? key,
    required this.listOfAddCard,this.index = 0
  }) : super(key: key);
  final int index;
  final List<CardInList> listOfAddCard;

  @override
  Widget build(BuildContext context) {
    if(listOfAddCard[index].isImage){
      return Image(image: NetworkImage(listOfAddCard[index].imageUrl),);


    }else{
      return Card(
        elevation:8,
        child: Stack(
          children: [
            Positioned(
                top: 20,
                right: 20,
                child: Hero(
                    tag:listOfAddCard[index].heading,
                    child:       Text(listOfAddCard[index].heading,style: GoogleFonts.actor(letterSpacing: 1.5,decoration: TextDecoration.none,fontWeight: FontWeight.bold,color: Colors.white,fontSize: kIsWeb?20:15),)
                )),
            Positioned(
              top: 20,
              left: 20,
              child: ClipRRect(
                borderRadius: BorderRadius.all(Radius.circular(20)),
                child: Container(
                  height: 40,
                  width: 40,
                  color: Colors.white,
                  child: Center(
                    child:Icon(Icons.list,color: Colors.black,),
                  ),
                ),
              ),
            ),
            Positioned(
              bottom: 10,
              left: 20,
              child: Container(
                width: 240,
                height: 40,
                child: Text(listOfAddCard[index].description,
                  overflow: TextOverflow.fade,
                  style: GoogleFonts.actor(color: Colors.white70),),
              ),
            ),
          ],
        ),color: listOfAddCard[index].cardBackground,
      );
    }

  }
}


class CardInList{
  CardType cardType = CardType.list;
  IconData icon = Icons.list;
  Color cardBackground ;
  String heading;
  String description = '';
  Function onTap;
  bool isImage;
  String imageUrl;
  CardInList({this.isImage = false,this.imageUrl = '',required this.heading,this.description = '',this.cardBackground = Colors.black87,required this.onTap});
}

enum CardType{
  list,
  advertisement,
}
